@@ -930,7 +930,7 @@ def python():
 import pickle
 
 def opensource(module='pyextension'):
-    if module == 'pyextension':
+    if module == 'pyextension' or module == '__init__':
         file = open('__init__.py')
         get = file.read()
         file.close()
@@ -974,3 +974,18 @@ def message():
 
 def description():
     return DESCRIPTION
+
+def _test():
+    computer
+    computer()
+    python
+    python()
+    opensource('pyextension')
+    opensource('math')
+    opensource('password')
+    opensource('word')
+    opensource('word bank')
+    opensource('word bank data')
+    license()
+    message()
+    description()
